import React, { useState, useEffect } from 'react';
import { Form, Input, Button, Icon, Select, message, Table, Divider, Tag, Pagination, Modal, DatePicker } from 'antd';
import { FormattedMessage } from 'umi-plugin-react/locale';
import styles from '../../style/GoodsList.less';
import router from 'umi/router';
import moment from 'moment';
import SelectCity from '../../../components/SelectButton/CitySelect'
import BuildSelect from '../../../components/SelectButton/BuildSelect'
import apis from '../../../services/apis';
import request from '../../../utils/request';
import AuthButton from '@/components/AuthButton';

const { Option } = Select;
const { MonthPicker, RangePicker, WeekPicker } = DatePicker;

const header = props => {
  const [data, setData] = useState({})
  const [demend, setDemend] = useState({})

  useEffect(() => {
    getList({ pageNum: 1, pageSize: 10 });
  }, [])

  // 查询列表
  const getList = (params) => {
    console.log(params);
    request({ ...apis.taH5SampleManager.tataH5Demand, params: { ...params } }).then((data) => {
      console.log(data)
      setData(data)
    })
  }


  // 跳转到拼团活动新增
  const toEditActivity = (groupActivityId) => () => {
    router.push({
      pathname: '/activity/groupActivity/editGroupActivity',
      query: {
        groupActivityId
      },
    });
  }

  const getActivityDetail = (groupActivityId) => () => {
    router.push({
      pathname: '/activity/groupActivity/detailActivity',
      query: {
        groupActivityId,
      },
    });
  } 

  const getJoinPeople = (groupActivityId) => () => {
    router.push({
      pathname: '/activity/groupActivity/helpRecord',
      query: {
          groupActivityId,
      },
    });
  } 

  // 跳转到编辑
  const toDetail = rowData => () => {
    if(rowData) {
      router.push({
      pathname: '/h5SampleManager/h5Demand/detail',
      query: {
        id: rowData.demandId,
      },
    });
      return
    }
  }

  /**
   *
   *
   * @param {*} props
   * @returns
   */

  const columns = [
    {
      title: '样例名',
      dataIndex: 'sampleName',
      key: 'sampleName',
      align: 'center',
    },
    {
      title: '下单人',
      dataIndex: 'orderer',
      key: 'orderer',
      align: 'center',
      
    },
    {
      title: '联系方式',
      dataIndex: 'phone',
      key: 'phone',
      align: 'center',
    },
    {
      title: '下单时间',
      dataIndex: 'createDate',
      key: 'createDate',
      align: 'center',
      render: (x, row) => <><span>{`${moment(row.startTime).format('YYYY-MM-DD HH:mm:ss')} —— ${moment(row.endTime).format('YYYY-MM-DD HH:mm:ss')}`}</span></>
    },
    {
      title: '需求单状态',
      dataIndex: 'demandStatus',
      key: 'demandStatus',
      align: 'center',
      render: (text, records) => {
        if (records.demandStatus === 1) { return '已提交' }
        if (records.demandStatus === 2) { return '处理中' }
        if (records.demandStatus === 3) { return '已交付' }
        if (records.demandStatus === 4) { return '作废' }
      },
    },
    {
      title: '操作',
      dataIndex: 'handle',
      key: 'handle',
      align: 'center',
      render: (text, record) => (
        <AuthButton name="admin.raise.detail.get" noRight={null}>
          <a style={{ color: '#66B3FF' }} onClick={toDetail(record)} >查看详情</a>
        </AuthButton>
      ),
    },
  ];
  
  const rowSelection = {
    onChange: (selectedRowKeys, selectedRows) => {
      console.log('selectedRowKeys:', selectedRowKeys, 'selectedRows: ', selectedRows);
      setDemend(selectedRows)
    },
  };

  const changePageNum = pageNumber => {
    getList({ pageNum: pageNumber, pageSize: 10, ...props.form.getFieldsValue() })
  }

  // 提交事件
  const handleSubmit = (e, props) => {
    e.preventDefault();
    props.form.validateFields((err, values) => {
      if (!err) {
        console.log('提交数据: ', values)
        getList({ pageNum: 1, pageSize: 10, ...values })
      }
    });
  }

  //重置搜索
  function handleReset () {
    props.form.resetFields();
    getList({ pageNum: 1, pageSize: 10 })
  }


  const { getFieldDecorator } = props.form
  return (

    <>
      <Form layout="inline" onSubmit={e => handleSubmit(e, props)}>
        <Form.Item>
          {getFieldDecorator('sampleName')(
            <Input
            prefix={<Icon type="text" style={{ color: 'rgba(0,0,0,.25)' }} />}
            placeholder="样例名"
          />,
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('orderer')(
            <Input
            prefix={<Icon type="text" style={{ color: 'rgba(0,0,0,.25)' }} />}
            placeholder="下单人"
          />,
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('phone')(
            <Input
              prefix={<Icon type="text" style={{ color: 'rgba(0,0,0,.25)' }} />}
              placeholder="联系方式1"
            />,
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('createDate')(
            <RangePicker placeholder={['开始时间','结束时间']}/>
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('createDate')(
            <Select style={{ width: '180px' }} placeholder="需求单状态">
                <option value="">全部</option>
                <option value="1">已提交</option>
                <option value="2">处理中</option>
                <option value="3">已交付</option>
                <option value="4">作废</option>
            </Select>
          )}
        </Form.Item>
        <Form.Item>
            <AuthButton name="admin.taShareActivity.search" noRight={null}>
                <Button type="primary" htmlType="submit" className={styles.searchBtn}>
                    搜索
                </Button>
            </AuthButton>
            <AuthButton name="admin.taShareActivity.search" noRight={null}>
                <Button style={{ marginLeft: 8 }} onClick={handleReset}>
                        重置
                </Button>
            </AuthButton>
        </Form.Item>
      </Form>
      <AuthButton name="admin.taShareActivity.post" noRight={null}>
        <Button type="danger" className={styles.addBtn} onClick={toEditActivity()}>新增</Button>
      </AuthButton>
      <AuthButton name="admin.taShareActivity.post" noRight={null}>
        <Button type="primary" className={styles.addBtn} onClick={toEditActivity()} style={{marginLeft:'30px'}}>删除</Button>
      </AuthButton>
      <Table rowSelection={rowSelection}
        style={{marginTop:'30px'}} dataSource={data.records} columns={columns} pagination={false} rowKey="activityList" />
      <div style={{ display: 'flex', justifyContent: 'flex-end', marginTop: '30px' }}>
        <Pagination showQuickJumper defaultCurrent={1} total={data.total} onChange={changePageNum} current={data.current} />
      </div>
    </>
  )
}
const WrappedHeader = Form.create({ name: 'header' })(header);

export default WrappedHeader
